# SignalFx Receiver

<!-- status autogenerated section -->
| Status                   |           |
| ------------------------ |-----------|
| Stability                | [beta]   |
| Supported pipeline types | metrics, logs   |
| Distributions            | [contrib] |

[beta]: https://github.com/open-telemetry/opentelemetry-collector#beta
[contrib]: https://github.com/open-telemetry/opentelemetry-collector-releases/tree/main/distributions/otelcol-contrib
<!-- end autogenerated section -->

The SignalFx receiver accepts:

- Metrics in the [SignalFx proto
format](https://github.com/signalfx/com_signalfx_metrics_protobuf).
- Events (Logs) in the [SignalFx proto
format](https://github.com/signalfx/com_signalfx_metrics_protobuf/blob/master/proto/signalfx_metrics.proto#L137).
More information about sending custom events can be found in the [SignalFx
Developers
Guide](https://developers.signalfx.com/ingest_data_reference.html#tag/Send-Custom-Events).

## Configuration

The following settings are required:

- `endpoint` (default = `0.0.0.0:9943`): Address and port that the SignalFx
  receiver should bind to.

The following settings are optional:

- `access_token_passthrough`: (default = `false`) Whether to preserve incoming
  access token (`X-Sf-Token` header value) as
  `"com.splunk.signalfx.access_token"` metric resource attribute.  Should only be
  used in tandem with identical configuration option for [SignalFx
  exporter](../../exporter/signalfxexporter/README.md) to preserve datapoint
  origin.  Usage of any other exporter in a metric pipeline with this configuration
  option enabled will reveal all organization access tokens contained in this attribute.
- `tls_settings` (no default): This is an optional object used to specify if
  TLS should be used for incoming connections. Both `key_file` and `cert_file`
  are required to support incoming TLS connections.
    - `cert_file`: Specifies the certificate file to use for TLS connection.
    - `key_file`: Specifies the key file to use for TLS connection.

Example:

```yaml
receivers:
  signalfx:
  signalfx/advanced:
    access_token_passthrough: true
    tls:
      cert_file: /test.crt
      key_file: /test.key
```

The full list of settings exposed for this receiver are documented [here](./config.go)
with detailed sample configurations [here](./testdata/config.yaml).

> :warning: When enabling the SignalFx receiver or exporter, configure both the `metrics` and `logs` pipelines.

```yaml
service:
  pipelines:
    metrics:
      receivers: [signalfx]
      processors: [memory_limiter, batch]
      exporters: [signalfx]
    logs:
      receivers: [signalfx]
      processors: [memory_limiter, batch]
      exporters: [signalfx]
```
